﻿
/*
* getHolidayTextJapan
* Function	: 日本の祝日(振り替え休日、国民の休日を含む)の判定する。
* Input		: dtm 判定する日を表すDate Object
* 			: option	意味無し
* Return	: 祝日の場合その日を表す文字列、そうでない場合NULL
* Update	: 2018-11-08 2019年の天皇陛下即位日、即位礼正殿の儀を追加
*			:			 2020年以降体育の日をスポーツの日に変更
*			: 2020-05-12 2020年の海の日、山の日、スポーツの日を東京オリンピック・パラリンピック特別措置法に基づき変更
*/
function getHolidayTextJapan(dtm, option) {
	var year	= dtm.getFullYear();
	var yo		= dtm.getDay();
	var FURI = "振替休日";
	var temp1;
	var temp2;
	var title;
	
	title = getSyukuTitle(dtm);
	if (title != "") {
		// 祝日の場合
		return title;
	} else {
		// 振替休日
		if (year > 1973) {
			if (yo == 1) {
				if (getSyukuTitle(getShiftDay(dtm, -1)) != "") return FURI;
			} else if (year > 2006) {
				if (yo == 2) {
					if (getSyukuTitle(getShiftDay(dtm, -1)) != "" && getSyukuTitle(getShiftDay(dtm, -2)) != "") return FURI;
				} else if (yo == 3) {
					if (getSyukuTitle(getShiftDay(dtm, -1)) != "" && getSyukuTitle(getShiftDay(dtm, -2)) != "" && 
						getSyukuTitle(getShiftDay(dtm, -3)) != "") return FURI;
				}
			}
		}
		// 国民の休日
		if ((year > 1986) && getSyukuTitle(getShiftDay(dtm, -1)) != "" && getSyukuTitle(getShiftDay(dtm, 1)) != "") return "国民の休日";
	}
	return "";
}

/*
* getSyukuTitle
* Function	: 日本の祝日であるか判定する。振り替え休日、国民の休日を含まない。
* Input		: dtm 判定する日のDate Object
* Return	: 祝日の場合祝日名
*/
function getSyukuTitle(dtm) {		
	var year	= dtm.getFullYear();
	var month	= dtm.getMonth() + 1;
	var daycnt	= dtm.getDate();
	var yo		= dtm.getDay();

	// 月ごとの祝日処理
	switch (month) {
		case 1:
			if (daycnt == 1) return "元日";
			// 成人の日
			if (((year > 1999) && (yo == 1) && (Math.floor((daycnt - 1) / 7) == 1)) || ((year < 2000) && (daycnt == 15))) return "成人の日";
			break;
		case 2:
			if (daycnt == 11) return "建国記念の日";
			if ((year > 2019) && (daycnt == 23)) return "天皇誕生日";
			break
		case 3:
			// 春分の日
			if (daycnt == Math.floor(20.8431 + 0.242194 * (year - 1980)) - Math.floor((year  -1980) / 4)) return "春分の日";
			break;
		case 4:
			if (daycnt == 29) {
				if (year > 2006) {
					return "昭和の日";
				} else if (year > 1988) {
					return "みどりの日";
				} else {
					return "天皇誕生日";
				}
			}
			break;
		case 5:
			if ((daycnt == 1) && (year == 2019)) return "天皇陛下即位日";
			if (daycnt == 3) return "憲法記念日";
			if ((daycnt == 4) && (year > 2006)) return "みどりの日";
			if (daycnt == 5) return "こどもの日";
			break;
		case 6:
			break;
		case 7:
			// 海の日
			if (((year > 2002) && (year != 2020) && (yo == 1) && (Math.floor((daycnt - 1) / 7) == 2)) || ((year < 2003) && (year > 1995) && (daycnt == 20)) || ((year == 2020) && (daycnt == 23))) return "海の日";
			// スポーツの日
			if ((year == 2020) && (daycnt == 24)) return "スポーツの日";
			break;
		case 8:
			// 山の日
			if (((year > 2015) && (year != 2020) && (daycnt == 11)) || ((year == 2020) && (daycnt == 10))) return "山の日";
			break;
		case 9:
			// 敬老の日
			if (((year > 2002) && (yo == 1) && (Math.floor((daycnt - 1) / 7) == 2)) || ((year < 2003) && (daycnt == 15))) return "敬老の日";
			// 秋分の日
			if (daycnt == Math.floor(23.2488 + 0.242194 * (year - 1980)) - Math.floor((year - 1980) / 4)) return "秋分の日";
			break;
		case 10:
			// スポーツの日
			if ((year > 2020) &&  (yo == 1) && (Math.floor((daycnt - 1) / 7) == 1)) return "スポーツの日";
			// 体育の日
			if (((year > 1999) && (year < 2020) &&  (yo == 1) && (Math.floor((daycnt - 1) / 7) == 1)) | ((year < 2000) && (year > 1965) && (daycnt == 10))) return "体育の日";
			if ((daycnt == 22) && (year == 2019)) return "即位礼正殿の儀";
			break;
		case 11:
			if (daycnt == 3) return "文化の日";
			if (daycnt == 23) return "勤労感謝の日";
			break;
		case 12:
			if ((year > 1987) && (year < 2019) && (daycnt == 23)) return "天皇誕生日";
			break;
	}
	return "";
}
